==> cxf-services-xkms-common-4.0.3-sources.jar: org/apache/cxf/xkms/model/xkms/LocateRequestType.java <==

package org.apache.cxf.xkms.model.xkms;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for LocateRequestType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="LocateRequestType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}RequestAbstractType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}QueryKeyBinding"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LocateRequestType", propOrder = {
    "queryKeyBinding"
})
public class LocateRequestType
    extends RequestAbstractType
{

    @XmlElement(name = "QueryKeyBinding", required = true)
    protected QueryKeyBindingType queryKeyBinding = new QueryKeyBindingType();

    /**
     * Gets the value of the queryKeyBinding property.
     * 
     * @return
     *     possible object is
     *     {@link QueryKeyBindingType }
     *     
     */
    public QueryKeyBindingType getQueryKeyBinding() {
        return queryKeyBinding;
    }

    /**
     * Sets the value of the queryKeyBinding property.
     * 
     * @param value
     *     allowed object is
     *     {@link QueryKeyBindingType }
     *     
     */
    public void setQueryKeyBinding(QueryKeyBindingType value) {
        this.queryKeyBinding = value;
    }

}

==> cxf-services-xkms-common-4.1.1-sources.jar: org/apache/cxf/xkms/model/xkms/LocateRequestType.java <==

package org.apache.cxf.xkms.model.xkms;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for LocateRequestType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="LocateRequestType">
 *   <complexContent>
 *     <extension base="{http://www.w3.org/2002/03/xkms#}RequestAbstractType">
 *       <sequence>
 *         <element ref="{http://www.w3.org/2002/03/xkms#}QueryKeyBinding"/>
 *       </sequence>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LocateRequestType", propOrder = {
    "queryKeyBinding"
})
public class LocateRequestType
    extends RequestAbstractType
{

    @XmlElement(name = "QueryKeyBinding", required = true)
    protected QueryKeyBindingType queryKeyBinding = new QueryKeyBindingType();

    /**
     * Gets the value of the queryKeyBinding property.
     * 
     * @return
     *     possible object is
     *     {@link QueryKeyBindingType }
     *     
     */
    public QueryKeyBindingType getQueryKeyBinding() {
        return queryKeyBinding;
    }

    /**
     * Sets the value of the queryKeyBinding property.
     * 
     * @param value
     *     allowed object is
     *     {@link QueryKeyBindingType }
     *     
     */
    public void setQueryKeyBinding(QueryKeyBindingType value) {
        this.queryKeyBinding = value;
    }

}
